==> starship-0.53.0.tar.gz: starship-0.53.0/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug Report"
about: "If something isn't working as expected \U0001F914."
title: ''
labels: "\U0001F41B bug"
assignees: ''

---

<!--
─────────────────────────────────────────────
                                ⚠️ IMPORTANT: Please run the following command to create an issue:
                                                                         
                                                                            starship bug-report

                                      An issue will be pre-populated with your system's configuration, 
                                                          making the process a whole lot quicker 😊
─────────────────────────────────────────────
-->

## Bug Report

#### Current Behavior
<!-- A clear and concise description of the behavior. -->

#### Expected Behavior
<!-- A clear and concise description of what you expected to happen. -->

#### Additional context/Screenshots
<!-- Add any other context about the problem here. If applicable, add screenshots to help explain. -->

#### Possible Solution
<!--- Only if you have suggestions on a fix for the bug -->

#### Environment
- Starship version: [the output of `starship --version`]
- Shell type: [fish, zsh]
- Shell version: [the output of `fish --version` or `zsh --version`]
- Shell plugin manager: [e.g. oh-my-fish, oh-my-zsh, fisher, antigen]
- Terminal emulator: [e.g. iTerm, Hyper, Terminator]
- Operating system: [e.g. macOS 10.13.4, Windows 10]

#### Relevant Shell Configuration
<!-- 
  Based on the shell you use, please paste the appropriate configuration.
    Fish users: ~/.config/fish/config.fish
    Zsh users: ~/.zshrc
-->

```bash
# Your configuration here
```

#### Starship Configuration
<!-- Can be found in  ~/.config/starship.toml -->

```bash
# Your configuration here
```

==> starship-1.2.0.tar.gz: starship-1.2.0/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug Report"
about: "If something isn't working as expected \U0001F914."
title: ''
labels: "\U0001F41B bug"
assignees: ''

---

<!--
─────────────────────────────────────────────
  ⚠️ IMPORTANT: Please run the following command to create an issue:

  starship bug-report

  An issue will be pre-populated with your system's configuration,
  making the process a whole lot quicker 😊
─────────────────────────────────────────────
-->

## Bug Report

#### Current Behavior
<!-- A clear and concise description of the behavior. -->

#### Expected Behavior
<!-- A clear and concise description of what you expected to happen. -->

#### Additional context/Screenshots
<!-- Add any other context about the problem here. If applicable, add screenshots to help explain. -->

#### Possible Solution
<!--- Only if you have suggestions on a fix for the bug -->

#### Environment
- Starship version: [the output of `starship --version`]
- Shell type: [fish, zsh]
- Shell version: [the output of `fish --version` or `zsh --version`]
- Shell plugin manager: [if present, e.g. oh-my-fish, oh-my-zsh, fisher, antigen]
- Terminal emulator: [e.g. iTerm, Hyper, Terminator]
- Operating system: [e.g. macOS 10.13.4, Windows 10]

#### Relevant Shell Configuration
<!-- 
  Based on the shell you use, please paste the appropriate configuration.
  The default location for your shell is:
    Bash: ~/.bashrc
    Zsh: ~/.zshrc
    Fish: ~/.config/fish/config.fish
    Xonsh: ~/.config/xonsh/rc.xsh
    Elvish: ~/.config/elvish/rc.elv
    Nushell: ~/.config/nu/config.toml
    Ion: ~/.config/ion/initrc
-->

```
# Your configuration here
```

#### Starship Configuration
<!-- Can be found in  ~/.config/starship.toml -->

```toml
# Your configuration here
```
